# Loading libraries
library(ape)
library(xlsx)
library(plyr)
library(dplyr)
library(gdata)
library(ggplot2)
library(ape)
library(extrafont)
library(scales)
library(MASS)
library(PMCMR)
library(psych)
library(pheatmap)
library(RColorBrewer)
library(phyloseq)
library(vegan)
library(ggthemes)
library(gridExtra)
library(ggrepel)
library(phangorn)
library(picante)
library(reshape2)
library(reshape)
library(data.table)
source("miseqR.R")
library("ggpubr")


setwd("~/Dropbox/Collaborations/Michael Scharl/PSC")

My_Theme = theme(
  axis.title.x = element_text(size = 18),
  axis.text.x = element_text(size = 18),
  axis.title.y = element_text(size = 18),
  axis.text.y = element_text(size = 18))

# Loading necessary files for phyloseq #
otufile = "otu_table_curated_0.0001.biom"
treefile = "rep_set_tree.tre"
mapfile = "Biobank_Mapping_Merged_April_v4.txt"
mapfile = "PSC_map.txt"


Biobank_0.0001 <- merge_phyloseq (file,map,treefile)
saveRDS(Biobank_0.0001, "Biobank_0.0001.rds")

# Phyloseq Analysis
# Loading necessary files for phyloseq #
Biobank_0.0001 = readRDS("Biobank_0.0001.rds")
UC <- subset_samples(Biobank_0.0001, Disease == "UC")
UC_male <- subset_samples(UC, Gender == "Male")
UC_male_age50 <- subset_samples(UC_male, AgeAtSampling < 51)
UC_male_age50_MTWAI <- subset_samples(UC_male_age50, MTWAI < 11)
map<-sample_data(UC_male_age50_MTWAI)

UC<-Biobank_0.0001
UC
UC_Ord_PCoA_bray = ordinate(UC, "MDS", distance="bray") #Calculate Bray-Curtis dissimilarity

# PcoA Plot
Plot_Info_PSC <- plot_ordination(UC, UC_Ord_PCoA_bray, color = "Info_PSC") + geom_point(size=5, alpha=1) + theme_bw() + stat_ellipse(aes(group=Info_PSC))  + scale_colour_manual(values=c("#CC6666", "#3399FF")) + scale_fill_manual(values=c("#CC6666", "#3399FF"))
Plot_Info_PSC
ggsave(Plot_Info_PSC, file="Plot_Info_PSC_UC.pdf", width=11.69, height=8.27,useDingbats=FALSE)

# Clean up data before adonis for Bray-Curtis dissimilarity and use for all Beta Diversity Plots
UC_PSC<-UC
ent = prune_taxa(!(taxa_names(UC_PSC) %in% "-1"), UC_PSC)
ent = prune_taxa(taxa_sums(ent) > 0.0, ent)
ent <- transform_sample_counts(ent, function(x) x/sum(x))
ent <- subset_samples(ent, !is.na(UC_PSC))
df = data.frame(sample_data(ent))
BC = distance(ent, "bray")


# Stat_Beta_Diversity
Stat_Beta_Diversity <- adonis(BC ~ Info_PSC, data=df)
Stat_Beta_Diversity
beta <- betadisper(BC, df$Info_PSC)
permutest(beta)

# Alpha Diversity

p <- plot_anova_diversity(UC_PSC, method = c("simpson", "shannon"), 
                          grouping_column = "Info_PSC", pValueCutoff = 0.2) + My_Theme + theme(legend.text = element_text(size = 16, colour = "black"), legend.title = element_text(size = 20,face = "bold")) + scale_color_discrete(name="Info_PSC") 

p <- p + scale_colour_manual(values=c("#CC6666", "#3399FF")) + scale_fill_manual(values=c("#3399FF", "#CC6666"))
print(p)
ggsave(p, file="Alpha Diversity Plot_Info_PSC_UC.pdf", width=16.00, height=14.00,useDingbats=FALSE)

alpha_diversity_UC_PSC <-estimate_richness(UC_PSC, split = TRUE, measures = NULL) 
data_cbind <- cbind(sample_data(UC_PSC), alpha_diversity_UC_PSC)
write.csv(data_cbind,"data_cbind.csv")


fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/metadata.txt", "~/Desktop/PSC/Taxonomy", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)




# PTPN2 -------------------------------------------------------------------
UC_PTPN2 <- subset_samples(UC_PSC, rs1893217_PTPN2 != "Unknown")
UC_PTPN2_TT <- subset_samples(UC_PSC, rs1893217_PTPN2 == "T")

UC_PTPN2_TT_Ord_PCoA_bray = ordinate(UC_PTPN2_TT, "MDS", distance="bray") #Calculate Bray-Curtis dissimilarity

# PcoA Plot
Plot_Info_PSC <- plot_ordination(UC_PTPN2_TT, UC_PTPN2_TT_Ord_PCoA_bray, color = "Info_PSC") + geom_point(size=5, alpha=1) + theme_bw() + stat_ellipse(aes(group=Info_PSC))  + scale_colour_manual(values=c("#CC6666", "#3399FF")) + scale_fill_manual(values=c("#CC6666", "#3399FF"))
Plot_Info_PSC
ggsave(Plot_Info_PSC, file="Plot_Info_PSC_UC_PTPN2_TT.pdf", width=11.69, height=8.27,useDingbats=FALSE)

# Clean up data before adonis for Bray-Curtis dissimilarity and use for all Beta Diversity Plots
UC_PTPN2_TT_PSC<-UC_PTPN2_TT
ent = prune_taxa(!(taxa_names(UC_PTPN2_TT_PSC) %in% "-1"), UC_PTPN2_TT_PSC)
ent = prune_taxa(taxa_sums(ent) > 0.0, ent)
ent <- transform_sample_counts(ent, function(x) x/sum(x))
ent <- subset_samples(ent, !is.na(UC_PTPN2_TT_PSC))
df = data.frame(sample_data(ent))
BC = distance(ent, "bray")


# Stat_Beta_Diversity
Stat_Beta_Diversity <- adonis(BC ~ Info_PSC, data=df)
Stat_Beta_Diversity
beta <- betadisper(BC, df$Info_PSC)
permutest(beta)

# Alpha Diversity

p <- plot_anova_diversity(UC_PTPN2_TT_PSC, method = c("simpson", "shannon"), 
                          grouping_column = "Info_PSC", pValueCutoff = 0.2) + My_Theme + theme(legend.text = element_text(size = 16, colour = "black"), legend.title = element_text(size = 20,face = "bold")) + scale_color_discrete(name="Info_PSC") 

p <- p + scale_colour_manual(values=c("#CC6666", "#3399FF")) + scale_fill_manual(values=c("#3399FF", "#CC6666"))
print(p)
ggsave(p, file="Alpha Diversity Plot_Info_PSC_UC_PTPN2_TT.pdf", width=16.00, height=14.00,useDingbats=FALSE)

alpha_diversity_UC_PTPN2_TT_PSC <-estimate_richness(UC_PTPN2_TT_PSC, split = TRUE, measures = NULL) 
data_cbind <- cbind(sample_data(UC_PTPN2_TT_PSC), alpha_diversity_UC_PTPN2_TT_PSC)
write.csv(data_cbind,"data_cbind.csv")


fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_PTPN2_TT", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/ileum_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_ileum_PTPN2_TT", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/rectum_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_rectum_PTPN2_TT", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/rightcolon_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_rightcolon_PTPN2_TT", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Biobank_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/leftcolon_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_leftcolon_PTPN2_TT", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)



# Control Included
# Phyloseq Analysis
# Loading necessary files for phyloseq #
# Combining Biobank and Clinical Data
setwd("~/Dropbox/Collaborations/Michael Scharl/PSC/CombinedCohorts")
otufile = "otu_table_curated_0.0001.biom"
treefile = "rep_set_tree.tre"
mapfile = "Combined_PSC_map.txt"

file <-import_biom(otufile)
treefile <- read.tree("rep_set_tree.tre")
map <-import_qiime_sample_data(mapfile)


Combined_0.0001 <- merge_phyloseq (file,map,treefile)
saveRDS(Combined_0.0001, "Combined_0.0001.rds")


UC<-Combined_0.0001
UC
UC_Ord_PCoA_bray = ordinate(UC, "MDS", distance="bray") #Calculate Bray-Curtis dissimilarity

# PcoA Plot
Plot_Info_PSC <- plot_ordination(UC, UC_Ord_PCoA_bray, color = "Info_PSC") + geom_point(size=5, alpha=1) + theme_bw() + stat_ellipse(aes(group=Info_PSC)) 
Plot_Info_PSC
ggsave(Plot_Info_PSC, file="Plot_Info_PSC_UC_Control_Together.pdf", width=11.69, height=8.27,useDingbats=FALSE)

# Clean up data before adonis for Bray-Curtis dissimilarity and use for all Beta Diversity Plots
UC_PSC<-UC
ent = prune_taxa(!(taxa_names(UC_PSC) %in% "-1"), UC_PSC)
ent = prune_taxa(taxa_sums(ent) > 0.0, ent)
ent <- transform_sample_counts(ent, function(x) x/sum(x))
ent <- subset_samples(ent, !is.na(UC_PSC))
df = data.frame(sample_data(ent))
BC = distance(ent, "bray")


# Stat_Beta_Diversity
Stat_Beta_Diversity <- adonis(BC ~ Info_PSC, data=df)
Stat_Beta_Diversity
beta <- betadisper(BC, df$Info_PSC)
permutest(beta)

# Alpha Diversity

p <- plot_anova_diversity(UC_PSC, method = c("simpson", "shannon"), 
                          grouping_column = "Info_PSC", pValueCutoff = 0.2) + My_Theme + theme(legend.text = element_text(size = 16, colour = "black"), legend.title = element_text(size = 20,face = "bold")) + scale_color_discrete(name="Info_PSC") 

p <- p + scale_colour_manual(values=c("#CC6666", "#3399FF")) + scale_fill_manual(values=c("#3399FF", "#CC6666"))
print(p)
ggsave(p, file="Alpha Diversity Plot_Info_PSC_UC_Control_Together.pdf", width=16.00, height=14.00,useDingbats=FALSE)

alpha_diversity_UC_PSC <-estimate_richness(UC_PSC, split = TRUE, measures = NULL) 
data_cbind <- cbind(sample_data(UC_PSC), alpha_diversity_UC_PSC)
write.csv(data_cbind,"data_cbind.csv")


fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/metadata.txt", "~/Desktop/PSC/Taxonomy", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)



UC_PTPN2 <- subset_samples(UC_PSC, rs1893217_PTPN2 != "Unknown")
UC_PTPN2_TT <- subset_samples(UC_PSC, rs1893217_PTPN2 %in% c("T","Non-IBD"))
UC_PTPN2_TT_Ord_PCoA_bray = ordinate(UC_PTPN2_TT, "PCoA", distance="bray") #Calculate Bray-Curtis dissimilarity

# PcoA Plot
Plot_Info_PSC <- plot_ordination(UC_PTPN2_TT, UC_PTPN2_TT_Ord_PCoA_bray, color = "Info_PSC") + geom_point(size=5, alpha=1) + theme_bw() + stat_ellipse(aes(group=Info_PSC))
Plot_Info_PSC
ggsave(Plot_Info_PSC, file="Plot_Info_PSC_UC_Control_Together_PTPN2_TT.pdf", width=11.69, height=8.27,useDingbats=FALSE)
# Clean up data before adonis for Bray-Curtis dissimilarity and use for all Beta Diversity Plots
UC_PTPN2_TT_PSC<-UC_PTPN2_TT
ent = prune_taxa(!(taxa_names(UC_PTPN2_TT_PSC) %in% "-1"), UC_PTPN2_TT_PSC)
ent = prune_taxa(taxa_sums(ent) > 0.0, ent)
ent <- transform_sample_counts(ent, function(x) x/sum(x))
ent <- subset_samples(ent, !is.na(UC_PTPN2_TT_PSC))
df = data.frame(sample_data(ent))
BC = distance(ent, "bray")

# Stat_Beta_Diversity
Stat_Beta_Diversity <- adonis(BC ~ Info_PSC, data=df)
Stat_Beta_Diversity
beta <- betadisper(BC, df$Info_PSC)
permutest(beta)

# Alpha Diversity
p <- plot_anova_diversity(UC_PTPN2_TT_PSC, method = c("simpson", "shannon"), 
                          grouping_column = "Info_PSC", pValueCutoff = 0.05) + My_Theme + theme(legend.text = element_text(size = 16, colour = "black"), legend.title = element_text(size = 20,face = "bold")) + scale_color_discrete(name="Info_PSC") 

print(p)
ggsave(p, file="Alpha Diversity Plot_Info_PSC_UC__Control_Together_PTPN2_TT.pdf", width=16.00, height=14.00,useDingbats=FALSE)



UC_PTPN2_CT <- subset_samples(UC_PSC, rs1893217_PTPN2 %in% c("CT","Non-IBD"))
UC_PTPN2_CT_Ord_PCoA_bray = ordinate(UC_PTPN2_CT, "PCoA", distance="bray") #Calculate Bray-Curtis dissimilarity

# PcoA Plot
Plot_Info_PSC <- plot_ordination(UC_PTPN2_CT, UC_PTPN2_CT_Ord_PCoA_bray, color = "Info_PSC") + geom_point(size=5, alpha=1) + theme_bw() + stat_ellipse(aes(group=rs1893217_PTPN2))
Plot_Info_PSC
ggsave(Plot_Info_PSC, file="Plot_Info_PSC_UC_Control_Together_PTPN2_CT.pdf", width=11.69, height=8.27,useDingbats=FALSE)
# Clean up data before adonis for Bray-Curtis dissimilarity and use for all Beta Diversity Plots
UC_PTPN2_CT_PSC<-UC_PTPN2_CT
ent = prune_taxa(!(taxa_names(UC_PTPN2_CT_PSC) %in% "-1"), UC_PTPN2_CT_PSC)
ent = prune_taxa(taxa_sums(ent) > 0.0, ent)
ent <- transform_sample_counts(ent, function(x) x/sum(x))
ent <- subset_samples(ent, !is.na(UC_PTPN2_CT_PSC))
df = data.frame(sample_data(ent))
BC = distance(ent, "bray")

# Stat_Beta_Diversity
Stat_Beta_Diversity <- adonis(BC ~ Info_PSC, data=df)
Stat_Beta_Diversity
beta <- betadisper(BC, df$Info_PSC)
permutest(beta)

# Alpha Diversity
p <- plot_anova_diversity(UC_PTPN2_CT_PSC, method = c("simpson", "shannon"), 
                          grouping_column = "Info_PSC", pValueCutoff = 0.05) + My_Theme + theme(legend.text = element_text(size = 16, colour = "black"), legend.title = element_text(size = 20,face = "bold")) + scale_color_discrete(name="Info_PSC") 

print(p)
ggsave(p, file="Alpha Diversity Plot_Info_PSC_UC_Control_Together_PTPN2_CT.pdf", width=16.00, height=14.00,useDingbats=FALSE)

fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_PTPN2_TT_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/ileum_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_ileum_PTPN2_TT_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/rectum_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_rectum_PTPN2_TT_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/rightcolon_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_rightcolon_PTPN2_TT_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/leftcolon_PTPN2_TT.txt", "~/Desktop/PSC/Taxonomy_leftcolon_PTPN2_TT_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)

fit_data <- Maaslin2("~/Desktop/PSC/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/PSC/PTPN2_CT_T.txt", "~/Desktop/PSC/All_Location_Taxonomy_PTPN2_CT_T_with_Control", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)


# All Patients
setwd("~/Desktop")
fit_data <- Maaslin2("~/Desktop/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/Ileum_all_patients.txt", "~/Desktop/Ileum_all_patients", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/rectum_all_patients.txt", "~/Desktop/Rectum_all_patients", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/colon_left_all_patients.txt", "~/Desktop/Colon_left_all_patients", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)
fit_data <- Maaslin2("~/Desktop/Combined_L6_April2017_0.0001_Maaslin_All.txt", "~/Desktop/colon_right_all_patients.txt", "~/Desktop/Colon_right_all_patients", min_abundance=0.00001, min_prevalence=0.3, max_significance=0.2)

# ileum
input_metadata = read.table("Ileum_all_patients.txt", header=TRUE,row.names="sample")
input_data_bacteria = read.table("Combined_L6_April2017_0.0001_Maaslin_All.txt", header=TRUE,row.names="sample")


input_metadata_ileum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "PSC"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_ileum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'Ileum_NoPSC_PSC',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_ileum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_ileum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'Ileum_NoPSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_ileum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("PSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_ileum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'Ileum_PSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

# rectum
input_metadata = read.table("rectum_all_patients.txt", header=TRUE,row.names="sample")
input_data_bacteria = read.table("Combined_L6_April2017_0.0001_Maaslin_All.txt", header=TRUE,row.names="sample")


input_metadata_rectum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "PSC"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_rectum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'rectum_NoPSC_PSC',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_rectum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_rectum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'rectum_NoPSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_rectum <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("PSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_rectum, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'rectum_PSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)


# colon_left
input_metadata = read.table("colon_left_all_patients.txt", header=TRUE,row.names="sample")
input_data_bacteria = read.table("Combined_L6_April2017_0.0001_Maaslin_All.txt", header=TRUE,row.names="sample")


input_metadata_colon_left <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "PSC"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_left, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_left_NoPSC_PSC',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_colon_left <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_left, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_left_NoPSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_colon_left <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("PSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_left, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_left_PSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)



# colon_right
input_metadata = read.table("colon_right_all_patients.txt", header=TRUE,row.names="sample")
input_data_bacteria = read.table("Combined_L6_April2017_0.0001_Maaslin_All.txt", header=TRUE,row.names="sample")


input_metadata_colon_right <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "PSC"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_right, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_right_NoPSC_PSC',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_colon_right <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("NoPSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_right, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_right_NoPSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)

input_metadata_colon_right <- input_metadata  %>%  
  tibble::rownames_to_column('sample') %>% 
  dplyr::filter(Info_PSC %in% c("PSC", "Non-IBD"))  %>% 
  tibble::column_to_rownames('sample')
input_data<-select(input_metadata_colon_right, Info_PSC)
fit_data <- Maaslin2(
  input_data_bacteria, input_data, 'colon_right_PSC_Non-IBD',  min_abundance=0.00000001,min_prevalence=0.3, max_significance=0.287, 
  standardize = FALSE)






